@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2010-2017 The pygit2 contributors
+# Copyright 2010-2019 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -54,7 +54,7 @@ from .ffi import ffi, C
 from .index import Index
 from .remote import RemoteCollection
 from .blame import Blame
-from .utils import to_bytes, is_string
+from .utils import to_bytes, is_string, StrArray
 from .submodule import Submodule
 
 
@@ -64,6 +64,8 @@ class BaseRepository(_Repository):
         self._common_init()
 
     def _common_init(self):
+        self.branches = Branches(self)
+        self.references = References(self)
         self.remotes = RemoteCollection(self)
 
         # Get the pointer as the contents of a buffer and store it for
@@ -202,7 +204,7 @@ class BaseRepository(_Repository):
     # Checkout
     #
     @staticmethod
-    def _checkout_args_to_options(strategy=None, directory=None):
+    def _checkout_args_to_options(strategy=None, directory=None, paths=None):
         # Create the options struct to pass
         copts = ffi.new('git_checkout_options *')
         check_error(C.git_checkout_init_options(copts, 1))
@@ -221,6 +223,11 @@ class BaseRepository(_Repository):
             refs.append(target_dir)
             copts.target_directory = target_dir
 
+        if paths:
+            strarray = StrArray(paths)
+            refs.append(strarray)
+            copts.paths = strarray.array[0]
+
         return copts, refs
 
     def checkout_head(self, **kwargs):
@@ -271,6 +278,10 @@ class BaseRepository(_Repository):
         directory : str
             Alternative checkout path to workdir.
 
+        paths : list[str]
+            A list of files to checkout from the given reference.
+            If paths is provided, HEAD will not be set to the reference.
+
         Examples:
 
         * To checkout from the HEAD, just pass 'HEAD'::
@@ -299,7 +310,8 @@ class BaseRepository(_Repository):
         treeish = self[oid]
         self.checkout_tree(treeish, **kwargs)
 
-        self.set_head(refname)
+        if 'paths' not in kwargs:
+            self.set_head(refname)
 
     #
     # Setting HEAD
@@ -834,7 +846,7 @@ class BaseRepository(_Repository):
 
         Example::
 
-            >>> repo = pygit2.Repsitory('.')
+            >>> repo = pygit2.Repository('.')
             >>> repo.stash(repo.default_signature(), 'WIP: stashing')
         """
 
@@ -888,7 +900,7 @@ class BaseRepository(_Repository):
 
         Example::
 
-            >>> repo = pygit2.Repsitory('.')
+            >>> repo = pygit2.Repository('.')
             >>> repo.stash(repo.default_signature(), 'WIP: stashing')
             >>> repo.stash_apply(strategy=GIT_CHECKOUT_ALLOW_CONFLICTS)
         """
@@ -946,7 +958,7 @@ class BaseRepository(_Repository):
 
             >>> import tarfile, pygit2
             >>>> with tarfile.open('foo.tar', 'w') as archive:
-            >>>>     repo = pygit2.Repsitory('.')
+            >>>>     repo = pygit2.Repository('.')
             >>>>     repo.write_archive(repo.head.target, archive)
         """
 
@@ -1130,13 +1142,19 @@ class BaseRepository(_Repository):
 
 
 class Branches(object):
-    def __init__(self, repository, flag=GIT_BRANCH_ALL):
+    def __init__(self, repository, flag=GIT_BRANCH_ALL, commit=None):
         self._repository = repository
         self._flag = flag
+        if commit is not None:
+            if isinstance(commit, Commit):
+                commit = commit.id
+            elif not isinstance(commit, Oid):
+                commit = self._repository.expand_id(commit)
+        self._commit = commit
 
         if flag == GIT_BRANCH_ALL:
-            self.local = Branches(repository, flag=GIT_BRANCH_LOCAL)
-            self.remote = Branches(repository, flag=GIT_BRANCH_REMOTE)
+            self.local = Branches(repository, flag=GIT_BRANCH_LOCAL, commit=commit)
+            self.remote = Branches(repository, flag=GIT_BRANCH_REMOTE, commit=commit)
 
     def __getitem__(self, name):
         branch = None
@@ -1146,7 +1164,7 @@ class Branches(object):
         if branch is None and self._flag & GIT_BRANCH_REMOTE:
             branch = self._repository.lookup_branch(name, GIT_BRANCH_REMOTE)
 
-        if branch is None:
+        if branch is None or not self._valid(branch):
             raise KeyError('Branch not found: {}'.format(name))
 
         return branch
@@ -1159,7 +1177,8 @@ class Branches(object):
 
     def __iter__(self):
         for branch_name in self._repository.listall_branches(self._flag):
-            yield branch_name
+            if self._commit is None or self.get(branch_name) is not None:
+                yield branch_name
 
     def create(self, name, commit, force=False):
         return self._repository.create_branch(name, commit, force)
@@ -1167,6 +1186,14 @@ class Branches(object):
     def delete(self, name):
         self[name].delete()
 
+    def _valid(self, branch):
+        return (self._commit is None or branch.target == self._commit or
+                self._repository.descendant_of(branch.target, self._commit))
+
+    def with_commit(self, commit):
+        assert self._commit is None
+        return Branches(self._repository, self._flag, commit)
+
     def __contains__(self, name):
         return self.get(name) is not None
 
@@ -1210,9 +1237,6 @@ class Repository(BaseRepository):
         path_backend = init_file_backend(path)
         super(Repository, self).__init__(backend=path_backend, *args, **kwargs)
 
-        self.branches = Branches(self)
-        self.references = References(self)
-
     @classmethod
     def _from_c(cls, ptr, owned):
         cptr = ffi.new('git_repository **')
