@@ -1,5 +1,5 @@
 /*
- * Copyright 2010-2017 The pygit2 contributors
+ * Copyright 2010-2019 The pygit2 contributors
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2,
@@ -74,6 +74,7 @@ wrap_diff_file(const git_diff_file *file)
     if (py_file) {
         py_file->id = git_oid_to_python(&file->id);
         py_file->path = file->path != NULL ? strdup(file->path) : NULL;
+        py_file->raw_path = file->path != NULL ? PyBytes_FromString(file->path) : NULL;
         py_file->size = file->size;
         py_file->flags = file->flags;
         py_file->mode = file->mode;
@@ -108,8 +109,7 @@ wrap_diff_hunk(Patch *patch, size_t idx)
 {
     DiffHunk *py_hunk;
     const git_diff_hunk *hunk;
-    const git_diff_line *line;
-    size_t j, lines_in_hunk;
+    size_t lines_in_hunk;
     int err;
 
     err = git_patch_get_hunk(&hunk, &lines_in_hunk, patch->patch, idx);
@@ -177,6 +177,7 @@ DiffFile_dealloc(DiffFile *self)
 PyMemberDef DiffFile_members[] = {
     MEMBER(DiffFile, id, T_OBJECT, "Oid of the item."),
     MEMBER(DiffFile, path, T_STRING, "Path to the entry."),
+    MEMBER(DiffFile, raw_path, T_OBJECT, "Path to the entry (bytes)."),
     MEMBER(DiffFile, size, T_LONG, "Size of the entry."),
     MEMBER(DiffFile, flags, T_UINT, "Combination of GIT_DIFF_FLAG_* flags."),
     MEMBER(DiffFile, mode, T_USHORT, "Mode of the entry."),
@@ -687,8 +688,6 @@ DiffHunk_lines__get__(DiffHunk *self)
     // TODO Replace by an iterator
     py_lines = PyList_New(self->n_lines);
     for (i = 0; i < self->n_lines; ++i) {
-        PyObject *py_line = NULL;
-
         err = git_patch_get_line_in_hunk(&line, self->patch->patch, self->idx, i);
         if (err < 0)
             return Error_set(err);
