@@ -1,5 +1,5 @@
 /*
- * Copyright 2010-2017 The pygit2 contributors
+ * Copyright 2010-2019 The pygit2 contributors
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2,
@@ -40,26 +40,21 @@ PyTypeObject PatchType;
 
 
 PyObject *
-wrap_patch(git_patch *patch)
+wrap_patch(git_patch *patch, Blob *oldblob, Blob *newblob)
 {
     Patch *py_patch;
-    PyObject *py_hunk;
-    size_t i, hunk_amounts;
 
-    if (!patch)
-        Py_RETURN_NONE;
+    assert(patch);
 
     py_patch = PyObject_New(Patch, &PatchType);
     if (py_patch) {
         py_patch->patch = patch;
 
-        hunk_amounts = git_patch_num_hunks(patch);
-        py_patch->hunks = PyList_New(hunk_amounts);
-        for (i = 0; i < hunk_amounts; ++i) {
-            py_hunk = wrap_diff_hunk(patch, i);
-            if (py_hunk)
-                PyList_SetItem((PyObject*) py_patch->hunks, i, py_hunk);
-        }
+        Py_XINCREF(oldblob);
+        py_patch->oldblob = oldblob;
+
+        Py_XINCREF(newblob);
+        py_patch->newblob = newblob;
     }
 
     return (PyObject*) py_patch;
@@ -68,7 +63,8 @@ wrap_patch(git_patch *patch)
 static void
 Patch_dealloc(Patch *self)
 {
-    Py_CLEAR(self->hunks);
+    Py_CLEAR(self->oldblob);
+    Py_CLEAR(self->newblob);
     git_patch_free(self->patch);
     PyObject_Del(self);
 }
@@ -78,9 +74,7 @@ PyDoc_STRVAR(Patch_delta__doc__, "Get the delta associated with a patch.");
 PyObject *
 Patch_delta__get__(Patch *self)
 {
-    if (!self->patch)
-        Py_RETURN_NONE;
-
+    assert(self->patch);
     return wrap_diff_delta(git_patch_get_delta(self->patch));
 }
 
@@ -93,11 +87,8 @@ Patch_line_stats__get__(Patch *self)
     size_t context, additions, deletions;
     int err;
 
-    if (!self->patch)
-        Py_RETURN_NONE;
-
-    err = git_patch_line_stats(&context, &additions, &deletions,
-                               self->patch);
+    assert(self->patch);
+    err = git_patch_line_stats(&context, &additions, &deletions, self->patch);
     if (err < 0)
         return Error_set(err);
 
@@ -108,7 +99,7 @@ PyDoc_STRVAR(Patch_create_from__doc__,
     "Create a patch from blobs, buffers, or a blob and a buffer");
 
 static PyObject *
-Patch_create_from(PyObject *self, PyObject *args)
+Patch_create_from(PyObject *self, PyObject *args, PyObject *kwds)
 {
   /* A generic wrapper around
    * git_patch_from_blob_and_buffer
@@ -119,24 +110,30 @@ Patch_create_from(PyObject *self, PyObject *args)
   git_patch *patch;
   char *old_as_path = NULL, *new_as_path = NULL;
   PyObject *oldobj = NULL, *newobj = NULL;
+  Blob *oldblob = NULL, *newblob = NULL;
+  const char *oldbuf = NULL, *newbuf = NULL;
+  Py_ssize_t oldbuflen, newbuflen;
   int err;
 
-  if (!PyArg_ParseTuple(args, "OzOz|I", &oldobj, &old_as_path, &newobj,
-                        &new_as_path, &opts.flags))
+  char *keywords[] = {"old", "new", "old_as_path", "new_as_path",
+                      "flag", "context_lines", "interhunk_lines",
+                      NULL};
+
+  if (!PyArg_ParseTupleAndKeywords(args, kwds, "OO|zzIHH", keywords,
+                                   &oldobj, &newobj, &old_as_path, &new_as_path,
+                                   &opts.flags, &opts.context_lines,
+                                   &opts.interhunk_lines))
     return NULL;
 
   if (oldobj != Py_None && PyObject_TypeCheck(oldobj, &BlobType))
   {
     /* The old object exists and is a blob */
-    Blob *oldblob = NULL;
     if (!PyArg_Parse(oldobj, "O!", &BlobType, &oldblob))
       return NULL;
 
     if (newobj != Py_None && PyObject_TypeCheck(newobj, &BlobType))
     {
       /* The new object exists and is a blob */
-      Blob *newblob = NULL;
-
       if (!PyArg_Parse(newobj, "O!", &BlobType, &newblob))
         return NULL;
 
@@ -145,8 +142,6 @@ Patch_create_from(PyObject *self, PyObject *args)
     }
     else {
       /* The new object does not exist or is a buffer */
-      const char* newbuf = NULL;
-      Py_ssize_t newbuflen;
       if (!PyArg_Parse(newobj, "z#", &newbuf, &newbuflen))
         return NULL;
 
@@ -158,8 +153,6 @@ Patch_create_from(PyObject *self, PyObject *args)
   else
   {
     /* The old object does exist and is a buffer */
-    const char *oldbuf = NULL, *newbuf = NULL;
-    Py_ssize_t oldbuflen, newbuflen;
     if (!PyArg_Parse(oldobj, "z#", &oldbuf, &oldbuflen))
       return NULL;
 
@@ -169,12 +162,11 @@ Patch_create_from(PyObject *self, PyObject *args)
     err = git_patch_from_buffers(&patch, oldbuf, oldbuflen, old_as_path,
                                  newbuf, newbuflen, new_as_path, &opts);
   }
-  
+
   if (err < 0)
     return Error_set(err);
 
-  return wrap_patch(patch);
-    
+  return wrap_patch(patch, oldblob, newblob);
 }
 
 
@@ -184,39 +176,54 @@ PyDoc_STRVAR(Patch_patch__doc__,
 PyObject *
 Patch_patch__get__(Patch *self)
 {
-  if (!self->patch)
-      Py_RETURN_NONE;
+    git_buf buf = {NULL};
+    int err;
+    PyObject *py_patch;
 
-  git_buf buf = {NULL};
-  int err = GIT_ERROR;
-  PyObject *py_patch = NULL;
+    assert(self->patch);
+    err = git_patch_to_buf(&buf, self->patch);
+    if (err < 0)
+        return Error_set(err);
 
-  err = git_patch_to_buf(&buf, self->patch);
-  if (err < 0)
-    goto cleanup;
-
-  py_patch = to_unicode(buf.ptr, NULL, NULL);
-  git_buf_free(&buf);
-
-cleanup:
+    py_patch = to_unicode(buf.ptr, NULL, NULL);
     git_buf_free(&buf);
-    return (err < 0) ? Error_set(err) : py_patch;
+    return py_patch;
 }
 
+PyDoc_STRVAR(Patch_hunks__doc__, "hunks");
+
+PyObject *
+Patch_hunks__get__(Patch *self)
+{
+    size_t i, hunk_amounts;
+    PyObject *py_hunks;
+    PyObject *py_hunk;
+
+    hunk_amounts = git_patch_num_hunks(self->patch);
+    py_hunks = PyList_New(hunk_amounts);
+    for (i = 0; i < hunk_amounts; i++) {
+        py_hunk = wrap_diff_hunk(self, i);
+        if (py_hunk == NULL)
+            return NULL;
+
+        PyList_SET_ITEM((PyObject*) py_hunks, i, py_hunk);
+    }
+
+    return py_hunks;
+}
+
+
 PyMethodDef Patch_methods[] = {
-    {"create_from", (PyCFunction) Patch_create_from, METH_VARARGS | METH_STATIC, Patch_create_from__doc__},
+    {"create_from", (PyCFunction) Patch_create_from,
+      METH_KEYWORDS | METH_VARARGS | METH_STATIC, Patch_create_from__doc__},
     {NULL}
 };
 
-PyMemberDef Patch_members[] = {
-    MEMBER(Patch, hunks, T_OBJECT, "hunks"),
-    {NULL}
-};
-
-PyGetSetDef Patch_getseters[] = {
+PyGetSetDef Patch_getsetters[] = {
     GETTER(Patch, delta),
     GETTER(Patch, patch),
     GETTER(Patch, line_stats),
+    GETTER(Patch, hunks),
     {NULL}
 };
 
@@ -251,8 +258,8 @@ PyTypeObject PatchType = {
     0,                                         /* tp_iter           */
     0,                                         /* tp_iternext       */
     Patch_methods,                             /* tp_methods        */
-    Patch_members,                             /* tp_members        */
-    Patch_getseters,                           /* tp_getset         */
+    0,                                         /* tp_members        */
+    Patch_getsetters,                          /* tp_getset         */
     0,                                         /* tp_base           */
     0,                                         /* tp_dict           */
     0,                                         /* tp_descr_get      */
