@@ -1,5 +1,5 @@
 /*
- * Copyright 2010-2017 The pygit2 contributors
+ * Copyright 2010-2019 The pygit2 contributors
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2,
@@ -42,6 +42,7 @@ extern PyObject *GitError;
 extern PyTypeObject RefLogEntryType;
 extern PyTypeObject SignatureType;
 
+PyTypeObject ReferenceType;
 
 void RefLogIter_dealloc(RefLogIter *self)
 {
@@ -306,6 +307,15 @@ Reference_name__get__(Reference *self)
     return to_path(git_reference_name(self->reference));
 }
 
+PyDoc_STRVAR(Reference_raw_name__doc__, "The full name of the reference (Bytes).");
+
+PyObject *
+Reference_raw_name__get__(Reference *self)
+{
+    CHECK_REFERENCE(self);
+    return PyBytes_FromString(git_reference_name(self->reference));
+}
+
 PyDoc_STRVAR(Reference_shorthand__doc__,
     "The shorthand \"human-readable\" name of the reference.");
 
@@ -316,6 +326,16 @@ Reference_shorthand__get__(Reference *self)
     return to_path(git_reference_shorthand(self->reference));
 }
 
+PyDoc_STRVAR(Reference_raw_shorthand__doc__,
+    "The shorthand \"human-readable\" name of the reference (Bytes).");
+
+PyObject *
+Reference_raw_shorthand__get__(Reference *self)
+{
+    CHECK_REFERENCE(self);
+    return PyBytes_FromString(git_reference_shorthand(self->reference));
+}
+
 PyDoc_STRVAR(Reference_type__doc__,
     "Type, either GIT_REF_OID or GIT_REF_SYMBOLIC.");
 
@@ -357,19 +377,6 @@ Reference_log(Reference *self)
     return (PyObject*)iter;
 }
 
-PyDoc_STRVAR(Reference_get_object__doc__,
-  "get_object() -> object\n"
-  "\n"
-  "Retrieves the object the current reference is pointing to.\n"
-  "\n"
-  "This method is deprecated, please use Reference.peel() instead.");
-
-PyObject *
-Reference_get_object(Reference *self)
-{
-    return PyObject_CallMethod((PyObject *) self, "peel", NULL);
-}
-
 PyDoc_STRVAR(Reference_peel__doc__,
   "peel(type=None) -> object\n"
   "\n"
@@ -401,6 +408,70 @@ Reference_peel(Reference *self, PyObject *args)
     return wrap_object(obj, self->repo);
 }
 
+PyObject *
+Reference_richcompare(PyObject *o1, PyObject *o2, int op)
+{
+    PyObject *res;
+    Reference *obj1;
+    Reference *obj2;
+    const char *name1;
+    const char *name2;
+
+    if (!PyObject_TypeCheck(o2, &ReferenceType)) {
+        Py_INCREF(Py_NotImplemented);
+        return Py_NotImplemented;
+    }
+
+    switch (op) {
+        case Py_NE:
+            obj1 = (Reference *) o1;
+            obj2 = (Reference *) o2;
+
+            CHECK_REFERENCE(obj1);
+            CHECK_REFERENCE(obj2);
+
+            name1 = git_reference_name(obj1->reference);
+            name2 = git_reference_name(obj2->reference);
+
+            if (strcmp(name1, name2) != 0) {
+                res = Py_True;
+                break;
+            }
+
+            res = Py_False;
+            break;
+        case Py_EQ:
+            obj1 = (Reference *) o1;
+            obj2 = (Reference *) o2;
+
+            CHECK_REFERENCE(obj1);
+            CHECK_REFERENCE(obj2);
+
+            name1 = git_reference_name(obj1->reference);
+            name2 = git_reference_name(obj2->reference);
+
+            if (strcmp(name1, name2) != 0) {
+                res = Py_False;
+                break;
+            }
+
+            res = Py_True;
+            break;
+        case Py_LT:
+        case Py_LE:
+        case Py_GT:
+        case Py_GE:
+            Py_INCREF(Py_NotImplemented);
+            return Py_NotImplemented;
+        default:
+            PyErr_Format(PyExc_RuntimeError, "Unexpected '%d' op", op);
+            return NULL;
+    }
+
+    Py_INCREF(res);
+    return res;
+}
+
 PyDoc_STRVAR(RefLogEntry_committer__doc__, "Committer.");
 
 PyObject *
@@ -493,7 +564,6 @@ PyMethodDef Reference_methods[] = {
     METHOD(Reference, rename, METH_O),
     METHOD(Reference, resolve, METH_NOARGS),
     METHOD(Reference, log, METH_NOARGS),
-    METHOD(Reference, get_object, METH_NOARGS),
     METHOD(Reference, set_target, METH_VARARGS | METH_KEYWORDS),
     METHOD(Reference, peel, METH_VARARGS),
     {NULL}
@@ -501,7 +571,9 @@ PyMethodDef Reference_methods[] = {
 
 PyGetSetDef Reference_getseters[] = {
     GETTER(Reference, name),
+    GETTER(Reference, raw_name),
     GETTER(Reference, shorthand),
+    GETTER(Reference, raw_shorthand),
     GETTER(Reference, target),
     GETTER(Reference, type),
     {NULL}
@@ -534,7 +606,7 @@ PyTypeObject ReferenceType = {
     Reference__doc__,                          /* tp_doc            */
     0,                                         /* tp_traverse       */
     0,                                         /* tp_clear          */
-    0,                                         /* tp_richcompare    */
+    Reference_richcompare,                     /* tp_richcompare    */
     0,                                         /* tp_weaklistoffset */
     0,                                         /* tp_iter           */
     0,                                         /* tp_iternext       */
