@@ -1,5 +1,5 @@
 /*
- * Copyright 2010-2017 The pygit2 contributors
+ * Copyright 2010-2019 The pygit2 contributors
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2,
@@ -35,8 +35,10 @@
 #include "oid.h"
 #include "note.h"
 #include "repository.h"
+#include "diff.h"
 #include "branch.h"
 #include "signature.h"
+#include "worktree.h"
 #include <git2/odb_backend.h>
 #include <git2/sys/repository.h>
 
@@ -518,6 +520,9 @@ PyDoc_STRVAR(Repository_path__doc__,
 PyObject *
 Repository_path__get__(Repository *self, void *closure)
 {
+    if (self->repo == NULL)
+      Py_RETURN_NONE;
+
     return to_path(git_repository_path(self->repo));
 }
 
@@ -559,6 +564,40 @@ Repository_workdir__set__(Repository *self, PyObject *py_workdir)
     return 0;
 }
 
+PyDoc_STRVAR(Repository_descendant_of__doc__,
+  "descendant_of(oid, oid) -> bool\n"
+  "\n"
+  "Determine if the first commit is a descendant of the second commit.\n"
+  "Note that a commit is not considered a descendant of itself.");
+
+PyObject *
+Repository_descendant_of(Repository *self, PyObject *args)
+{
+    PyObject *value1;
+    PyObject *value2;
+    git_oid oid1;
+    git_oid oid2;
+    int err;
+
+    if (!PyArg_ParseTuple(args, "OO", &value1, &value2))
+        return NULL;
+
+    err = py_oid_to_git_oid_expand(self->repo, value1, &oid1);
+    if (err < 0)
+        return NULL;
+
+    err = py_oid_to_git_oid_expand(self->repo, value2, &oid2);
+    if (err < 0)
+        return NULL;
+
+    // err < 0 => error, see source code of `git_graph_descendant_of`
+    err = git_graph_descendant_of(self->repo, &oid1, &oid2);
+    if (err < 0)
+        return Error_set(err);
+
+    return PyBool_FromLong(err);
+}
+
 PyDoc_STRVAR(Repository_merge_base__doc__,
   "merge_base(oid, oid) -> Oid\n"
   "\n"
@@ -1084,7 +1123,7 @@ PyDoc_STRVAR(Repository_create_branch__doc__,
   "\n"
   "Examples::\n"
   "\n"
-  "    repo.create_branch('foo', repo.head.get_object(), force=False)");
+  "    repo.create_branch('foo', repo.head.peel(), force=False)");
 
 PyObject *
 Repository_create_branch(Repository *self, PyObject *args)
@@ -1357,74 +1396,6 @@ Repository_init_submodules(Repository* self, PyObject *args, PyObject *kwds)
     Py_RETURN_NONE;
 }
 
-PyDoc_STRVAR(Repository_update_submodules__doc__,
-    "update_submodules(submodules=None, init=False)\n"
-    "\n"
-    "Updates the specified submodules, or all if None are specified\n"
-    "init: Flag indicating if submodules should be automatically initialized if necessary.\n");
-
-static int foreach_sub_update_cb(git_submodule *submodule, const char *name, void *payload)
-{
-    git_submodule_update_options opts = GIT_SUBMODULE_UPDATE_OPTIONS_INIT;
-    return git_submodule_update(submodule, *(int*)payload, &opts);
-}
-
-PyObject *
-Repository_update_submodules(Repository *self, PyObject *args, PyObject *kwds)
-{
-    PyObject *list = Py_None;
-    PyObject *py_init = Py_False;
-    PyObject *iter, *next, *subpath;
-    int init, err;
-    const char *c_subpath;
-    git_submodule *submodule;
-    git_submodule_update_options opts = GIT_SUBMODULE_UPDATE_OPTIONS_INIT;
-
-    char *kwlist[] = {"submodules", "init", NULL};
-
-    if (!PyArg_ParseTupleAndKeywords(args, kwds, "|OO", kwlist, &list, &py_init))
-        return NULL;
-
-    init = PyObject_IsTrue(py_init);
-
-    if (init != 0 && init != 1)
-        init = 0;
-
-    if (list == Py_None) {
-        err = git_submodule_foreach(self->repo, foreach_sub_update_cb, &init);
-        if (err != 0)
-            return Error_set(err);
-        Py_RETURN_NONE;
-    }
-
-    iter = PyObject_GetIter(list);
-    if (!iter)
-        return NULL;
-
-    while (1) {
-        next = PyIter_Next(iter);
-        if (!next)
-            break;
-
-        c_subpath = py_str_borrow_c_str(&subpath, next, NULL);
-
-        git_submodule_lookup(&submodule, self->repo, c_subpath);
-        Py_DECREF(subpath);
-        if (!submodule) {
-            PyErr_SetString(PyExc_KeyError,
-                "Submodule does not exist");
-            return NULL;
-        }
-
-        err = git_submodule_update(submodule, init, &opts);
-        if (err != 0) {
-            return Error_set(err);
-        }
-    }
-
-    Py_RETURN_NONE;
-}
-
 PyDoc_STRVAR(Repository_lookup_reference__doc__,
   "lookup_reference(name) -> Reference\n"
   "\n"
@@ -1532,7 +1503,6 @@ Repository_create_reference_symbolic(Repository *self,  PyObject *args,
     return wrap_reference(c_reference, self);
 }
 
-
 PyDoc_STRVAR(Repository_status__doc__,
   "status() -> {str: int}\n"
   "\n"
@@ -1858,6 +1828,87 @@ Repository_expand_id(Repository *self, PyObject *py_hex)
     return git_oid_to_python(&oid);
 }
 
+PyDoc_STRVAR(Repository_add_worktree__doc__,
+    "add_worktree(name, path)\n"
+    "\n"
+    "Create a new worktree for this repository.");
+PyObject *
+Repository_add_worktree(Repository *self, PyObject *args)
+{
+    char *c_name;
+    char *c_path;
+    git_worktree *wt;
+    int err;
+    git_worktree_add_options add_opts = GIT_WORKTREE_ADD_OPTIONS_INIT;
+
+    if (!PyArg_ParseTuple(args, "ss", &c_name, &c_path))
+        return NULL;
+
+    err = git_worktree_add(&wt, self->repo, c_name, c_path, &add_opts);
+    if (err < 0)
+        return Error_set(err);
+
+    return wrap_worktree(self, wt);
+}
+
+PyDoc_STRVAR(Repository_lookup_worktree__doc__,
+    "lookup_worktree(name) -> Worktree\n"
+    "\n"
+    "Lookup a worktree from its name.");
+PyObject *
+Repository_lookup_worktree(Repository *self, PyObject *args)
+{
+    char *c_name;
+    git_worktree *wt;
+    int err;
+
+    if (!PyArg_ParseTuple(args, "s", &c_name))
+        return NULL;
+
+    err = git_worktree_lookup(&wt, self->repo, c_name);
+    if (err < 0)
+        return Error_set(err);
+
+    return wrap_worktree(self, wt);
+}
+
+PyDoc_STRVAR(Repository_list_worktrees__doc__,
+    "list_worktrees() -> [str, ...]\n"
+    "\n"
+    "Return a list with all the worktrees of this repository.");
+PyObject *
+Repository_list_worktrees(Repository *self, PyObject *args)
+{
+    git_strarray c_result;
+    PyObject *py_result, *py_string;
+    unsigned index;
+    int err;
+
+    /* Get the C result */
+    err = git_worktree_list(&c_result, self->repo);
+    if (err < 0)
+        return Error_set(err);
+
+    /* Create a new PyTuple */
+    py_result = PyList_New(c_result.count);
+    if (py_result == NULL)
+        goto out;
+
+    /* Fill it */
+    for (index=0; index < c_result.count; index++) {
+        py_string = to_path(c_result.strings[index]);
+        if (py_string == NULL) {
+            Py_CLEAR(py_result);
+            goto out;
+        }
+        PyList_SET_ITEM(py_result, index, py_string);
+    }
+
+out:
+    git_strarray_free(&c_result);
+    return py_result;
+}
+
 PyMethodDef Repository_methods[] = {
     METHOD(Repository, create_blob, METH_VARARGS),
     METHOD(Repository, create_blob_fromworkdir, METH_VARARGS),
@@ -1867,6 +1918,7 @@ PyMethodDef Repository_methods[] = {
     METHOD(Repository, create_tag, METH_VARARGS),
     METHOD(Repository, TreeBuilder, METH_VARARGS),
     METHOD(Repository, walk, METH_VARARGS),
+    METHOD(Repository, descendant_of, METH_VARARGS),
     METHOD(Repository, merge_base, METH_VARARGS),
     METHOD(Repository, merge_analysis, METH_O),
     METHOD(Repository, merge, METH_O),
@@ -1879,7 +1931,6 @@ PyMethodDef Repository_methods[] = {
     METHOD(Repository, listall_reference_objects, METH_NOARGS),
     METHOD(Repository, listall_submodules, METH_NOARGS),
     METHOD(Repository, init_submodules, METH_VARARGS | METH_KEYWORDS),
-    METHOD(Repository, update_submodules, METH_VARARGS | METH_KEYWORDS),
     METHOD(Repository, lookup_reference, METH_O),
     METHOD(Repository, revparse_single, METH_O),
     METHOD(Repository, status, METH_NOARGS),
@@ -1895,6 +1946,9 @@ PyMethodDef Repository_methods[] = {
     METHOD(Repository, reset, METH_VARARGS),
     METHOD(Repository, free, METH_NOARGS),
     METHOD(Repository, expand_id, METH_O),
+    METHOD(Repository, add_worktree, METH_VARARGS),
+    METHOD(Repository, lookup_worktree, METH_VARARGS),
+    METHOD(Repository, list_worktrees, METH_VARARGS),
     METHOD(Repository, _from_c, METH_VARARGS),
     METHOD(Repository, _disown, METH_NOARGS),
     {NULL}
