@@ -1,5 +1,5 @@
 /*
- * Copyright 2010-2017 The pygit2 contributors
+ * Copyright 2010-2019 The pygit2 contributors
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2,
@@ -80,6 +80,19 @@ Tag_name__get__(Tag *self)
 }
 
 
+PyDoc_STRVAR(Tag_raw_name__doc__, "Tag name (bytes).");
+
+PyObject *
+Tag_raw_name__get__(Tag *self)
+{
+    const char *name;
+    name = git_tag_name(self->tag);
+    if (!name)
+        Py_RETURN_NONE;
+    return PyBytes_FromString(name);
+}
+
+
 PyDoc_STRVAR(Tag_tagger__doc__, "Tagger.");
 
 PyObject *
@@ -106,10 +119,10 @@ Tag_message__get__(Tag *self)
 }
 
 
-PyDoc_STRVAR(Tag__message__doc__, "Tag message (bytes).");
+PyDoc_STRVAR(Tag_raw_message__doc__, "Tag message (bytes).");
 
 PyObject *
-Tag__message__get__(Tag *self)
+Tag_raw_message__get__(Tag *self)
 {
     const char *message;
     message = git_tag_message(self->tag);
@@ -126,9 +139,10 @@ PyMethodDef Tag_methods[] = {
 PyGetSetDef Tag_getseters[] = {
     GETTER(Tag, target),
     GETTER(Tag, name),
+    GETTER(Tag, raw_name),
     GETTER(Tag, tagger),
     GETTER(Tag, message),
-    GETTER(Tag, _message),
+    GETTER(Tag, raw_message),
     {NULL}
 };
 
