@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 #
-# Copyright 2010-2017 The pygit2 contributors
+# Copyright 2010-2019 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -29,13 +29,12 @@
 
 from __future__ import absolute_import
 from __future__ import unicode_literals
-import unittest
-import pygit2
-from pygit2 import Index, Oid, Tree, Object
-import tarfile
+
 import os
+import tarfile
+
+from pygit2 import Index, Oid, Tree, Object
 from . import utils
-from time import time
 
 TREE_HASH = 'fd937514cb799514d4b81bb24c5fcfeb6472b245'
 COMMIT_HASH = '2be5719152d4f82c7302b1c0932d8e5f0a4a0e98'
@@ -52,14 +51,14 @@ class ArchiveTest(utils.RepoTestCase):
         else:
             index.read_tree(self.repo[treeish].peel(Tree))
 
-        self.assertEqual(len(index), len(archive.getmembers()))
+        assert len(index) == len(archive.getmembers())
 
         if timestamp:
             fileinfo = archive.getmembers()[0]
-            self.assertEqual(timestamp, fileinfo.mtime)
+            assert timestamp == fileinfo.mtime
 
         archive.close()
-        self.assertTrue(os.path.isfile('foo.tar'))
+        assert os.path.isfile('foo.tar')
         os.remove('foo.tar')
 
     def test_write_tree(self):
