@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 #
-# Copyright 2010-2017 The pygit2 contributors
+# Copyright 2010-2019 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -29,7 +29,8 @@
 
 from __future__ import absolute_import
 from __future__ import unicode_literals
-import unittest
+
+import pytest
 
 import pygit2
 from . import utils
@@ -37,84 +38,105 @@ from . import utils
 LAST_COMMIT = '2be5719152d4f82c7302b1c0932d8e5f0a4a0e98'
 I18N_LAST_COMMIT = '5470a671a80ac3789f1a6a8cefbcf43ce7af0563'
 ORIGIN_MASTER_COMMIT = '784855caf26449a1914d2cf62d12b9374d76ae78'
+EXCLUSIVE_MASTER_COMMIT = '5ebeeebb320790caf276b9fc8b24546d63316533'
+SHARED_COMMIT = '4ec4389a8068641da2d6578db0419484972284c8'
 
 
 class BranchesObjectTestCase(utils.RepoTestCase):
     def test_lookup_branch_local(self):
         branch = self.repo.branches['master']
-        self.assertEqual(branch.target.hex, LAST_COMMIT)
+        assert branch.target.hex == LAST_COMMIT
 
         branch = self.repo.branches.local['i18n']
-        self.assertEqual(branch.target.hex, I18N_LAST_COMMIT)
+        assert branch.target.hex == I18N_LAST_COMMIT
 
-        self.assertTrue(self.repo.branches.get('not-exists') is None)
+        assert self.repo.branches.get('not-exists') is None
 
-        self.assertRaises(KeyError, lambda: self.repo.branches['not-exists'])
+        with pytest.raises(KeyError): self.repo.branches['not-exists']
 
     def test_listall_branches(self):
         branches = sorted(self.repo.branches)
-        self.assertEqual(branches, ['i18n', 'master'])
+        assert branches == ['i18n', 'master']
 
     def test_create_branch(self):
         commit = self.repo[LAST_COMMIT]
         reference = self.repo.branches.create('version1', commit)
-        self.assertTrue('version1' in self.repo.branches)
+        assert 'version1' in self.repo.branches
         reference = self.repo.branches['version1']
-        self.assertEqual(reference.target.hex, LAST_COMMIT)
+        assert reference.target.hex == LAST_COMMIT
 
         # try to create existing reference
-        self.assertRaises(ValueError,
-                          lambda: self.repo.branches.create('version1', commit))
+        with pytest.raises(ValueError):
+            self.repo.branches.create('version1', commit)
 
         # try to create existing reference with force
         reference = self.repo.branches.create('version1', commit, True)
-        self.assertEqual(reference.target.hex, LAST_COMMIT)
+        assert reference.target.hex == LAST_COMMIT
 
     def test_delete(self):
         self.repo.branches.delete('i18n')
 
-        self.assertTrue(self.repo.branches.get('i18n') is None)
+        assert self.repo.branches.get('i18n') is None
 
     def test_cant_delete_master(self):
-        self.assertRaises(pygit2.GitError, lambda: self.repo.branches.delete('master'))
+        with pytest.raises(pygit2.GitError):
+            self.repo.branches.delete('master')
 
     def test_branch_is_head_returns_true_if_branch_is_head(self):
         branch = self.repo.branches.get('master')
-        self.assertTrue(branch.is_head())
+        assert branch.is_head()
 
     def test_branch_is_head_returns_false_if_branch_is_not_head(self):
         branch = self.repo.branches.get('i18n')
-        self.assertFalse(branch.is_head())
+        assert not branch.is_head()
 
     def test_branch_rename_succeeds(self):
         new_branch = self.repo.branches['i18n'].rename('new-branch')
-        self.assertEqual(new_branch.target.hex, I18N_LAST_COMMIT)
+        assert new_branch.target.hex == I18N_LAST_COMMIT
 
         new_branch_2 = self.repo.branches.get('new-branch')
-        self.assertEqual(new_branch_2.target.hex, I18N_LAST_COMMIT)
+        assert new_branch_2.target.hex == I18N_LAST_COMMIT
 
     def test_branch_rename_fails_if_destination_already_exists(self):
         original_branch = self.repo.branches.get('i18n')
-        self.assertRaises(ValueError, lambda: original_branch.rename('master'))
+        with pytest.raises(ValueError): original_branch.rename('master')
 
     def test_branch_rename_not_fails_if_force_is_true(self):
         original_branch = self.repo.branches.get('master')
         new_branch = original_branch.rename('i18n', True)
-        self.assertEqual(new_branch.target.hex, LAST_COMMIT)
+        assert new_branch.target.hex == LAST_COMMIT
 
     def test_branch_rename_fails_with_invalid_names(self):
         original_branch = self.repo.branches.get('i18n')
-        self.assertRaises(ValueError,
-                          lambda: original_branch.rename('abc@{123'))
+        with pytest.raises(ValueError):
+            original_branch.rename('abc@{123')
 
     def test_branch_name(self):
         branch = self.repo.branches.get('master')
-        self.assertEqual(branch.branch_name, 'master')
-        self.assertEqual(branch.name, 'refs/heads/master')
+        assert branch.branch_name == 'master'
+        assert branch.name == 'refs/heads/master'
 
         branch = self.repo.branches.get('i18n')
-        self.assertEqual(branch.branch_name, 'i18n')
-        self.assertEqual(branch.name, 'refs/heads/i18n')
+        assert branch.branch_name == 'i18n'
+        assert branch.name == 'refs/heads/i18n'
+
+    def test_with_commit(self):
+        branches = self.repo.branches.with_commit(EXCLUSIVE_MASTER_COMMIT)
+        assert sorted(branches) == ['master']
+        assert branches.get('i18n') is None
+        assert branches['master'].branch_name == 'master'
+
+        branches = self.repo.branches.with_commit(SHARED_COMMIT)
+        assert sorted(branches) == ['i18n', 'master']
+
+        branches = self.repo.branches.with_commit(LAST_COMMIT)
+        assert sorted(branches) == ['master']
+
+        branches = self.repo.branches.with_commit(self.repo[LAST_COMMIT])
+        assert sorted(branches) == ['master']
+
+        branches = self.repo.branches.remote.with_commit(LAST_COMMIT)
+        assert sorted(branches) == []
 
 
 class BranchesObjectEmptyRepoTestCase(utils.EmptyRepoTestCase):
@@ -126,19 +148,18 @@ class BranchesObjectEmptyRepoTestCase(utils.EmptyRepoTestCase):
 
     def test_lookup_branch_remote(self):
         branch = self.repo.branches.remote.get('origin/master')
-        self.assertEqual(branch.target.hex, ORIGIN_MASTER_COMMIT)
+        assert branch.target.hex == ORIGIN_MASTER_COMMIT
 
-        self.assertTrue(
-            self.repo.branches.remote.get('origin/not-exists') is None)
+        assert self.repo.branches.remote.get('origin/not-exists') is None
 
     def test_listall_branches(self):
         branches = sorted(self.repo.branches.remote)
-        self.assertEqual(branches, ['origin/master'])
+        assert branches == ['origin/master']
 
     def test_branch_remote_name(self):
         self.repo.remotes[0].fetch()
         branch = self.repo.branches.remote['origin/master']
-        self.assertEqual(branch.remote_name, 'origin')
+        assert branch.remote_name == 'origin'
 
     def test_branch_upstream(self):
         self.repo.remotes[0].fetch()
@@ -146,17 +167,17 @@ class BranchesObjectEmptyRepoTestCase(utils.EmptyRepoTestCase):
         master = self.repo.branches.create('master',
                                            self.repo[remote_master.target.hex])
 
-        self.assertTrue(master.upstream is None)
+        assert master.upstream is None
         master.upstream = remote_master
-        self.assertEqual(master.upstream.branch_name, 'origin/master')
+        assert master.upstream.branch_name == 'origin/master'
 
         def set_bad_upstream():
             master.upstream = 2.5
 
-        self.assertRaises(TypeError, set_bad_upstream)
+        with pytest.raises(TypeError): set_bad_upstream()
 
         master.upstream = None
-        self.assertTrue(master.upstream is None)
+        assert master.upstream is None
 
     def test_branch_upstream_name(self):
         self.repo.remotes[0].fetch()
@@ -165,96 +186,96 @@ class BranchesObjectEmptyRepoTestCase(utils.EmptyRepoTestCase):
                                            self.repo[remote_master.target.hex])
 
         master.upstream = remote_master
-        self.assertEqual(master.upstream_name, 'refs/remotes/origin/master')
+        assert master.upstream_name == 'refs/remotes/origin/master'
 
 
 class BranchesTestCase(utils.RepoTestCase):
     def test_lookup_branch_local(self):
         branch = self.repo.lookup_branch('master')
-        self.assertEqual(branch.target.hex, LAST_COMMIT)
+        assert branch.target.hex == LAST_COMMIT
 
         branch = self.repo.lookup_branch('i18n', pygit2.GIT_BRANCH_LOCAL)
-        self.assertEqual(branch.target.hex, I18N_LAST_COMMIT)
+        assert branch.target.hex == I18N_LAST_COMMIT
 
-        self.assertTrue(self.repo.lookup_branch('not-exists') is None)
+        assert self.repo.lookup_branch('not-exists') is None
 
     def test_listall_branches(self):
         branches = sorted(self.repo.listall_branches())
-        self.assertEqual(branches, ['i18n', 'master'])
+        assert branches == ['i18n', 'master']
 
     def test_create_branch(self):
         commit = self.repo[LAST_COMMIT]
         reference = self.repo.create_branch('version1', commit)
         refs = self.repo.listall_branches()
-        self.assertTrue('version1' in refs)
+        assert 'version1' in refs
         reference = self.repo.lookup_branch('version1')
-        self.assertEqual(reference.target.hex, LAST_COMMIT)
+        assert reference.target.hex == LAST_COMMIT
 
         # try to create existing reference
-        self.assertRaises(ValueError,
-                          lambda: self.repo.create_branch('version1', commit))
+        with pytest.raises(ValueError):
+            self.repo.create_branch('version1', commit)
 
         # try to create existing reference with force
         reference = self.repo.create_branch('version1', commit, True)
-        self.assertEqual(reference.target.hex, LAST_COMMIT)
+        assert reference.target.hex == LAST_COMMIT
 
     def test_delete(self):
         branch = self.repo.lookup_branch('i18n')
         branch.delete()
 
-        self.assertTrue(self.repo.lookup_branch('i18n') is None)
+        assert self.repo.lookup_branch('i18n') is None
 
     def test_cant_delete_master(self):
         branch = self.repo.lookup_branch('master')
 
-        self.assertRaises(pygit2.GitError, lambda: branch.delete())
+        with pytest.raises(pygit2.GitError): branch.delete()
 
     def test_branch_is_head_returns_true_if_branch_is_head(self):
         branch = self.repo.lookup_branch('master')
-        self.assertTrue(branch.is_head())
+        assert branch.is_head()
 
     def test_branch_is_head_returns_false_if_branch_is_not_head(self):
         branch = self.repo.lookup_branch('i18n')
-        self.assertFalse(branch.is_head())
+        assert not branch.is_head()
 
     def test_branch_is_checked_out_returns_true_if_branch_is_checked_out(self):
         branch = self.repo.lookup_branch('master')
-        self.assertTrue(branch.is_checked_out())
+        assert branch.is_checked_out()
 
     def test_branch_is_checked_out_returns_false_if_branch_is_not_checked_out(self):
         branch = self.repo.lookup_branch('i18n')
-        self.assertFalse(branch.is_checked_out())
+        assert not branch.is_checked_out()
 
     def test_branch_rename_succeeds(self):
         original_branch = self.repo.lookup_branch('i18n')
         new_branch = original_branch.rename('new-branch')
-        self.assertEqual(new_branch.target.hex, I18N_LAST_COMMIT)
+        assert new_branch.target.hex == I18N_LAST_COMMIT
 
         new_branch_2 = self.repo.lookup_branch('new-branch')
-        self.assertEqual(new_branch_2.target.hex, I18N_LAST_COMMIT)
+        assert new_branch_2.target.hex == I18N_LAST_COMMIT
 
     def test_branch_rename_fails_if_destination_already_exists(self):
         original_branch = self.repo.lookup_branch('i18n')
-        self.assertRaises(ValueError, lambda: original_branch.rename('master'))
+        with pytest.raises(ValueError): original_branch.rename('master')
 
     def test_branch_rename_not_fails_if_force_is_true(self):
         original_branch = self.repo.lookup_branch('master')
         new_branch = original_branch.rename('i18n', True)
-        self.assertEqual(new_branch.target.hex, LAST_COMMIT)
+        assert new_branch.target.hex == LAST_COMMIT
 
     def test_branch_rename_fails_with_invalid_names(self):
         original_branch = self.repo.lookup_branch('i18n')
-        self.assertRaises(ValueError,
-                          lambda: original_branch.rename('abc@{123'))
+        with pytest.raises(ValueError):
+            original_branch.rename('abc@{123')
 
     def test_branch_name(self):
         branch = self.repo.lookup_branch('master')
-        self.assertEqual(branch.branch_name, 'master')
-        self.assertEqual(branch.name, 'refs/heads/master')
+        assert branch.branch_name == 'master'
+        assert branch.name == 'refs/heads/master'
 
         branch = self.repo.lookup_branch('i18n')
-        self.assertEqual(branch.branch_name, 'i18n')
-        self.assertEqual(branch.name, 'refs/heads/i18n')
+        assert branch.branch_name == 'i18n'
+        assert branch.name == 'refs/heads/i18n'
 
 
 class BranchesEmptyRepoTestCase(utils.EmptyRepoTestCase):
@@ -267,21 +288,19 @@ class BranchesEmptyRepoTestCase(utils.EmptyRepoTestCase):
     def test_lookup_branch_remote(self):
         branch = self.repo.lookup_branch('origin/master',
                                          pygit2.GIT_BRANCH_REMOTE)
-        self.assertEqual(branch.target.hex, ORIGIN_MASTER_COMMIT)
+        assert branch.target.hex == ORIGIN_MASTER_COMMIT
 
-        self.assertTrue(
-            self.repo.lookup_branch('origin/not-exists',
-                                    pygit2.GIT_BRANCH_REMOTE) is None)
+        assert self.repo.lookup_branch('origin/not-exists', pygit2.GIT_BRANCH_REMOTE) is None
 
     def test_listall_branches(self):
         branches = sorted(self.repo.listall_branches(pygit2.GIT_BRANCH_REMOTE))
-        self.assertEqual(branches, ['origin/master'])
+        assert branches == ['origin/master']
 
     def test_branch_remote_name(self):
         self.repo.remotes[0].fetch()
         branch = self.repo.lookup_branch('origin/master',
                                          pygit2.GIT_BRANCH_REMOTE)
-        self.assertEqual(branch.remote_name, 'origin')
+        assert branch.remote_name == 'origin'
 
     def test_branch_upstream(self):
         self.repo.remotes[0].fetch()
@@ -290,17 +309,17 @@ class BranchesEmptyRepoTestCase(utils.EmptyRepoTestCase):
         master = self.repo.create_branch('master',
                                          self.repo[remote_master.target.hex])
 
-        self.assertTrue(master.upstream is None)
+        assert master.upstream is None
         master.upstream = remote_master
-        self.assertEqual(master.upstream.branch_name, 'origin/master')
+        assert master.upstream.branch_name == 'origin/master'
 
         def set_bad_upstream():
             master.upstream = 2.5
 
-        self.assertRaises(TypeError, set_bad_upstream)
+        with pytest.raises(TypeError): set_bad_upstream()
 
         master.upstream = None
-        self.assertTrue(master.upstream is None)
+        assert master.upstream is None
 
     def test_branch_upstream_name(self):
         self.repo.remotes[0].fetch()
@@ -310,8 +329,4 @@ class BranchesEmptyRepoTestCase(utils.EmptyRepoTestCase):
                                          self.repo[remote_master.target.hex])
 
         master.upstream = remote_master
-        self.assertEqual(master.upstream_name, 'refs/remotes/origin/master')
-
-
-if __name__ == '__main__':
-    unittest.main()
+        assert master.upstream_name == 'refs/remotes/origin/master'
