@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 #
-# Copyright 2010-2017 The pygit2 contributors
+# Copyright 2010-2019 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -29,14 +29,18 @@
 
 from __future__ import absolute_import
 from __future__ import unicode_literals
-import unittest
+
+from itertools import chain
+import textwrap
+
+import pytest
+
 import pygit2
 from pygit2 import GIT_DIFF_INCLUDE_UNMODIFIED
 from pygit2 import GIT_DIFF_IGNORE_WHITESPACE, GIT_DIFF_IGNORE_WHITESPACE_EOL
 from pygit2 import GIT_DIFF_SHOW_BINARY
 from pygit2 import GIT_DELTA_RENAMED
 from . import utils
-from itertools import chain
 
 
 COMMIT_SHA1_1 = '5fe808e8953c12735680c257f56600cb0de44b10'
@@ -131,11 +135,11 @@ class DiffDirtyTest(utils.DirtyRepoTestCase):
         head = repo[repo.lookup_reference('HEAD').resolve().target]
         diff = head.tree.diff_to_index(repo.index)
         files = [patch.delta.new_file.path for patch in diff]
-        self.assertEqual(DIFF_HEAD_TO_INDEX_EXPECTED, files)
+        assert DIFF_HEAD_TO_INDEX_EXPECTED == files
 
         diff = repo.diff('HEAD', cached=True)
         files = [patch.delta.new_file.path for patch in diff]
-        self.assertEqual(DIFF_HEAD_TO_INDEX_EXPECTED, files)
+        assert DIFF_HEAD_TO_INDEX_EXPECTED == files
 
     def test_workdir_to_tree(self):
         repo = self.repo
@@ -143,16 +147,16 @@ class DiffDirtyTest(utils.DirtyRepoTestCase):
 
         diff = head.tree.diff_to_workdir()
         files = [patch.delta.new_file.path for patch in diff]
-        self.assertEqual(DIFF_HEAD_TO_WORKDIR_EXPECTED, files)
+        assert DIFF_HEAD_TO_WORKDIR_EXPECTED == files
 
         diff = repo.diff('HEAD')
         files = [patch.delta.new_file.path for patch in diff]
-        self.assertEqual(DIFF_HEAD_TO_WORKDIR_EXPECTED, files)
+        assert DIFF_HEAD_TO_WORKDIR_EXPECTED == files
 
     def test_index_to_workdir(self):
         diff = self.repo.diff()
         files = [patch.delta.new_file.path for patch in diff]
-        self.assertEqual(DIFF_INDEX_TO_WORK_EXPECTED, files)
+        assert DIFF_INDEX_TO_WORK_EXPECTED == files
 
 
 class DiffTest(utils.BareRepoTestCase):
@@ -160,8 +164,8 @@ class DiffTest(utils.BareRepoTestCase):
     def test_diff_invalid(self):
         commit_a = self.repo[COMMIT_SHA1_1]
         commit_b = self.repo[COMMIT_SHA1_2]
-        self.assertRaises(TypeError, commit_a.tree.diff_to_tree, commit_b)
-        self.assertRaises(TypeError, commit_a.tree.diff_to_index, commit_b)
+        with pytest.raises(TypeError): commit_a.tree.diff_to_tree(commit_b)
+        with pytest.raises(TypeError): commit_a.tree.diff_to_index(commit_b)
 
     def test_diff_empty_index(self):
         repo = self.repo
@@ -169,36 +173,35 @@ class DiffTest(utils.BareRepoTestCase):
 
         diff = self.repo.index.diff_to_tree(head.tree)
         files = [patch.delta.new_file.path.split('/')[0] for patch in diff]
-        self.assertEqual([x.name for x in head.tree], files)
+        assert [x.name for x in head.tree] == files
 
         diff = head.tree.diff_to_index(repo.index)
         files = [patch.delta.new_file.path.split('/')[0] for patch in diff]
-        self.assertEqual([x.name for x in head.tree], files)
+        assert [x.name for x in head.tree] == files
 
         diff = repo.diff('HEAD', cached=True)
         files = [patch.delta.new_file.path.split('/')[0] for patch in diff]
-        self.assertEqual([x.name for x in head.tree], files)
+        assert [x.name for x in head.tree] == files
 
     def test_diff_tree(self):
         commit_a = self.repo[COMMIT_SHA1_1]
         commit_b = self.repo[COMMIT_SHA1_2]
 
         def _test(diff):
-            # self.assertIsNotNone is 2.7 only
-            self.assertTrue(diff is not None)
+            assert diff is not None
             # self.assertIn is 2.7 only
-            self.assertEqual(2, sum(map(lambda x: len(x.hunks), diff)))
+            assert 2 == sum(map(lambda x: len(x.hunks), diff))
 
             patch = diff[0]
             hunk = patch.hunks[0]
-            self.assertEqual(hunk.old_start, 1)
-            self.assertEqual(hunk.old_lines, 1)
-            self.assertEqual(hunk.new_start, 1)
-            self.assertEqual(hunk.new_lines, 1)
+            assert hunk.old_start == 1
+            assert hunk.old_lines == 1
+            assert hunk.new_start == 1
+            assert hunk.new_lines == 1
 
-            self.assertEqual(patch.delta.old_file.path, 'a')
-            self.assertEqual(patch.delta.new_file.path, 'a')
-            self.assertEqual(patch.delta.is_binary, False)
+            assert patch.delta.old_file.path == 'a'
+            assert patch.delta.new_file.path == 'a'
+            assert patch.delta.is_binary == False
 
         _test(commit_a.tree.diff_to_tree(commit_b.tree))
         _test(self.repo.diff(COMMIT_SHA1_1, COMMIT_SHA1_2))
@@ -214,17 +217,17 @@ class DiffTest(utils.BareRepoTestCase):
             return map(lambda x: x.origin, lines)
 
         entries = [p.delta.new_file.path for p in diff]
-        self.assertAll(lambda x: commit_a.tree[x], entries)
-        self.assertAll(lambda x: '-' == x, get_context_for_lines(diff))
+        assert all(commit_a.tree[x] for x in entries)
+        assert all('-' == x for x in get_context_for_lines(diff))
 
         diff_swaped = commit_a.tree.diff_to_tree(swap=True)
         entries = [p.delta.new_file.path for p in diff_swaped]
-        self.assertAll(lambda x: commit_a.tree[x], entries)
-        self.assertAll(lambda x: '+' == x, get_context_for_lines(diff_swaped))
+        assert all(commit_a.tree[x] for x in entries)
+        assert all('+' == x for x in get_context_for_lines(diff_swaped))
 
     def test_diff_revparse(self):
         diff = self.repo.diff('HEAD', 'HEAD~6')
-        self.assertEqual(type(diff), pygit2.Diff)
+        assert type(diff) == pygit2.Diff
 
     def test_diff_tree_opts(self):
         commit_c = self.repo[COMMIT_SHA1_3]
@@ -233,12 +236,12 @@ class DiffTest(utils.BareRepoTestCase):
         for flag in [GIT_DIFF_IGNORE_WHITESPACE,
                      GIT_DIFF_IGNORE_WHITESPACE_EOL]:
             diff = commit_c.tree.diff_to_tree(commit_d.tree, flag)
-            self.assertTrue(diff is not None)
-            self.assertEqual(0, len(diff[0].hunks))
+            assert diff is not None
+            assert 0 == len(diff[0].hunks)
 
         diff = commit_c.tree.diff_to_tree(commit_d.tree)
-        self.assertTrue(diff is not None)
-        self.assertEqual(1, len(diff[0].hunks))
+        assert diff is not None
+        assert 1 == len(diff[0].hunks)
 
     def test_diff_merge(self):
         commit_a = self.repo[COMMIT_SHA1_1]
@@ -246,48 +249,41 @@ class DiffTest(utils.BareRepoTestCase):
         commit_c = self.repo[COMMIT_SHA1_3]
 
         diff_b = commit_a.tree.diff_to_tree(commit_b.tree)
-        # self.assertIsNotNone is 2.7 only
-        self.assertTrue(diff_b is not None)
+        assert diff_b is not None
 
         diff_c = commit_b.tree.diff_to_tree(commit_c.tree)
-        # self.assertIsNotNone is 2.7 only
-        self.assertTrue(diff_c is not None)
-
-        # assertIn / assertNotIn are 2.7 only
-        self.assertFalse('b' in [patch.delta.new_file.path for patch in diff_b])
-        self.assertTrue('b' in [patch.delta.new_file.path for patch in diff_c])
+        assert diff_c is not None
+        assert 'b' not in [patch.delta.new_file.path for patch in diff_b]
+        assert 'b' in [patch.delta.new_file.path for patch in diff_c]
 
         diff_b.merge(diff_c)
-
-        # assertIn is 2.7 only
-        self.assertTrue('b' in [patch.delta.new_file.path for patch in diff_b])
+        assert 'b' in [patch.delta.new_file.path for patch in diff_b]
 
         patch = diff_b[0]
         hunk = patch.hunks[0]
-        self.assertEqual(hunk.old_start, 1)
-        self.assertEqual(hunk.old_lines, 1)
-        self.assertEqual(hunk.new_start, 1)
-        self.assertEqual(hunk.new_lines, 1)
+        assert hunk.old_start == 1
+        assert hunk.old_lines == 1
+        assert hunk.new_start == 1
+        assert hunk.new_lines == 1
 
-        self.assertEqual(patch.delta.old_file.path, 'a')
-        self.assertEqual(patch.delta.new_file.path, 'a')
+        assert patch.delta.old_file.path == 'a'
+        assert patch.delta.new_file.path == 'a'
 
     def test_diff_patch(self):
         commit_a = self.repo[COMMIT_SHA1_1]
         commit_b = self.repo[COMMIT_SHA1_2]
 
         diff = commit_a.tree.diff_to_tree(commit_b.tree)
-        self.assertEqual(diff.patch, PATCH)
-        self.assertEqual(len(diff), len([patch for patch in diff]))
+        assert diff.patch == PATCH
+        assert len(diff) == len([patch for patch in diff])
 
     def test_diff_ids(self):
         commit_a = self.repo[COMMIT_SHA1_1]
         commit_b = self.repo[COMMIT_SHA1_2]
         patch = commit_a.tree.diff_to_tree(commit_b.tree)[0]
-        self.assertEqual(patch.delta.old_file.id.hex,
-                         '7f129fd57e31e935c6d60a0c794efe4e6927664b')
-        self.assertEqual(patch.delta.new_file.id.hex,
-                         'af431f20fc541ed6d5afede3e2dc7160f6f01f16')
+        delta = patch.delta
+        assert delta.old_file.id.hex == '7f129fd57e31e935c6d60a0c794efe4e6927664b'
+        assert delta.new_file.id.hex == 'af431f20fc541ed6d5afede3e2dc7160f6f01f16'
 
     def test_hunk_content(self):
         commit_a = self.repo[COMMIT_SHA1_1]
@@ -295,7 +291,9 @@ class DiffTest(utils.BareRepoTestCase):
         patch = commit_a.tree.diff_to_tree(commit_b.tree)[0]
         hunk = patch.hunks[0]
         lines = ('{0} {1}'.format(x.origin, x.content) for x in hunk.lines)
-        self.assertEqual(HUNK_EXPECTED, ''.join(lines))
+        assert HUNK_EXPECTED == ''.join(lines)
+        for line in hunk.lines:
+            assert line.content == line.raw_content.decode()
 
     def test_find_similar(self):
         commit_a = self.repo[COMMIT_SHA1_6]
@@ -305,11 +303,11 @@ class DiffTest(utils.BareRepoTestCase):
         #~ --find-copies-harder during rename transformion...
         diff = commit_a.tree.diff_to_tree(commit_b.tree,
                                           GIT_DIFF_INCLUDE_UNMODIFIED)
-        self.assertAll(lambda x: x.delta.status != GIT_DELTA_RENAMED, diff)
-        self.assertAll(lambda x: x.delta.status_char() != 'R', diff)
+        assert all(x.delta.status != GIT_DELTA_RENAMED for x in diff)
+        assert all(x.delta.status_char() != 'R' for x in diff)
         diff.find_similar()
-        self.assertAny(lambda x: x.delta.status == GIT_DELTA_RENAMED, diff)
-        self.assertAny(lambda x: x.delta.status_char() == 'R', diff)
+        assert any(x.delta.status == GIT_DELTA_RENAMED for x in diff)
+        assert any(x.delta.status_char() == 'R' for x in diff)
 
     def test_diff_stats(self):
         commit_a = self.repo[COMMIT_SHA1_1]
@@ -317,23 +315,64 @@ class DiffTest(utils.BareRepoTestCase):
 
         diff = commit_a.tree.diff_to_tree(commit_b.tree)
         stats = diff.stats
-        self.assertEqual(1, stats.insertions)
-        self.assertEqual(2, stats.deletions)
-        self.assertEqual(2, stats.files_changed)
+        assert 1 == stats.insertions
+        assert 2 == stats.deletions
+        assert 2 == stats.files_changed
         formatted = stats.format(format=pygit2.GIT_DIFF_STATS_FULL |
                                         pygit2.GIT_DIFF_STATS_INCLUDE_SUMMARY,
                                  width=80)
-        self.assertEqual(STATS_EXPECTED, formatted)
+        assert STATS_EXPECTED == formatted
+
+    def test_deltas(self):
+        commit_a = self.repo[COMMIT_SHA1_1]
+        commit_b = self.repo[COMMIT_SHA1_2]
+        diff = commit_a.tree.diff_to_tree(commit_b.tree)
+        deltas = list(diff.deltas)
+        patches = list(diff)
+        assert len(deltas) == len(patches)
+        for i, delta in enumerate(deltas):
+            patch_delta = patches[i].delta
+            assert delta.status == patch_delta.status
+            assert delta.similarity == patch_delta.similarity
+            assert delta.nfiles == patch_delta.nfiles
+            assert delta.old_file.id == patch_delta.old_file.id
+            assert delta.new_file.id == patch_delta.new_file.id
+
+            # As explained in the libgit2 documentation, flags are not set
+            #assert delta.flags == patch_delta.flags
+
+    def test_diff_parse(self):
+        diff = pygit2.Diff.parse_diff(PATCH)
+
+        stats = diff.stats
+        assert 2 == stats.deletions
+        assert 1 == stats.insertions
+        assert 2 == stats.files_changed
+
+        deltas = list(diff.deltas)
+        assert 2 == len(deltas)
+
+    def test_parse_diff_null(self):
+        with pytest.raises(Exception):
+            self.repo.parse_diff(None)
+
+    def test_parse_diff_bad(self):
+        diff = textwrap.dedent(
+        """
+        diff --git a/file1 b/file1
+        old mode 0644
+        new mode 0644
+        @@ -1,1 +1,1 @@
+        -Hi!
+        """)
+        with pytest.raises(Exception):
+            self.repo.parse_diff(diff)
 
 
 class BinaryDiffTest(utils.BinaryFileRepoTestCase):
     def test_binary_diff(self):
         repo = self.repo
         diff = repo.diff('HEAD', 'HEAD^')
-        self.assertEqual(PATCH_BINARY, diff.patch)
+        assert PATCH_BINARY == diff.patch
         diff = repo.diff('HEAD', 'HEAD^', flags=GIT_DIFF_SHOW_BINARY)
-        self.assertEqual(PATCH_BINARY_SHOW, diff.patch)
-
-
-if __name__ == '__main__':
-    unittest.main()
+        assert PATCH_BINARY_SHOW == diff.patch
