@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 #
-# Copyright 2010-2017 The pygit2 contributors
+# Copyright 2010-2019 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -34,7 +34,8 @@ from __future__ import unicode_literals
 # Import from the Standard Library
 from binascii import unhexlify
 from sys import version_info
-import unittest
+
+import pytest
 
 # Import from pygit2
 from pygit2 import Oid
@@ -49,62 +50,58 @@ class OidTest(utils.BareRepoTestCase):
 
     def test_raw(self):
         oid = Oid(raw=RAW)
-        self.assertEqual(oid.raw, RAW)
-        self.assertEqual(str(oid), HEX)
+        assert oid.raw == RAW
+        assert str(oid) == HEX
 
     def test_hex(self):
         oid = Oid(hex=HEX)
-        self.assertEqual(oid.raw, RAW)
-        self.assertEqual(str(oid), HEX)
+        assert oid.raw == RAW
+        assert str(oid) == HEX
 
     def test_hex_bytes(self):
         if version_info[0] == 2:
             hex = bytes(HEX)
             oid = Oid(hex=hex)
-            self.assertEqual(oid.raw, RAW)
-            self.assertEqual(str(oid), HEX)
+            assert oid.raw == RAW
+            assert str(oid) == HEX
         else:
             hex = bytes(HEX, "ascii")
-            self.assertRaises(TypeError, Oid, hex=hex)
+            with pytest.raises(TypeError): Oid(hex=hex)
 
     def test_none(self):
-        self.assertRaises(ValueError, Oid)
+        with pytest.raises(ValueError): Oid()
 
     def test_both(self):
-        self.assertRaises(ValueError, Oid, raw=RAW, hex=HEX)
+        with pytest.raises(ValueError): Oid(raw=RAW, hex=HEX)
 
     def test_long(self):
-        self.assertRaises(ValueError, Oid, raw=RAW + b'a')
-        self.assertRaises(ValueError, Oid, hex=HEX + 'a')
+        with pytest.raises(ValueError): Oid(raw=RAW + b'a')
+        with pytest.raises(ValueError): Oid(hex=HEX + 'a')
 
     def test_cmp(self):
         oid1 = Oid(raw=RAW)
 
         # Equal
         oid2 = Oid(hex=HEX)
-        self.assertEqual(oid1, oid2)
+        assert oid1 == oid2
 
         # Not equal
         oid2 = Oid(hex="15b648aec6ed045b5ca6f57f8b7831a8b4757299")
-        self.assertNotEqual(oid1, oid2)
+        assert oid1 != oid2
 
         # Other
-        self.assertTrue(oid1 < oid2)
-        self.assertTrue(oid1 <= oid2)
-        self.assertFalse(oid1 == oid2)
-        self.assertFalse(oid1 > oid2)
-        self.assertFalse(oid1 >= oid2)
+        assert oid1 < oid2
+        assert oid1 <= oid2
+        assert not oid1 == oid2
+        assert not oid1 > oid2
+        assert not oid1 >= oid2
 
     def test_hash(self):
         s = set()
         s.add(Oid(raw=RAW))
         s.add(Oid(hex=HEX))
-        self.assertEqual(len(s), 1)
+        assert len(s) == 1
 
         s.add(Oid(hex="0000000000000000000000000000000000000000"))
         s.add(Oid(hex="0000000000000000000000000000000000000001"))
-        self.assertEqual(len(s), 3)
-
-
-if __name__ == '__main__':
-    unittest.main()
+        assert len(s) == 3
