@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 #
-# Copyright 2010-2017 The pygit2 contributors
+# Copyright 2010-2019 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -28,6 +28,8 @@
 from __future__ import absolute_import
 from __future__ import unicode_literals
 
+import pytest
+
 import pygit2
 from . import utils
 
@@ -94,7 +96,7 @@ class PatchTest(utils.RepoTestCase):
             new_as_path=BLOB_NEW_PATH,
         )
 
-        self.assertEqual(patch.patch, BLOB_PATCH)
+        assert patch.patch == BLOB_PATCH
 
     def test_patch_create_from_blobs(self):
         old_blob = self.repo[BLOB_OLD_SHA]
@@ -107,7 +109,7 @@ class PatchTest(utils.RepoTestCase):
             new_as_path=BLOB_NEW_PATH,
         )
 
-        self.assertEqual(patch.patch, BLOB_PATCH2)
+        assert patch.patch == BLOB_PATCH2
 
     def test_patch_create_from_blob_buffer(self):
         old_blob = self.repo[BLOB_OLD_SHA]
@@ -118,7 +120,7 @@ class PatchTest(utils.RepoTestCase):
             new_as_path=BLOB_NEW_PATH,
         )
 
-        self.assertEqual(patch.patch, BLOB_PATCH)
+        assert patch.patch == BLOB_PATCH
 
     def test_patch_create_from_blob_buffer_add(self):
         patch = pygit2.Patch.create_from(
@@ -128,7 +130,7 @@ class PatchTest(utils.RepoTestCase):
             new_as_path=BLOB_NEW_PATH,
         )
 
-        self.assertEqual(patch.patch, BLOB_PATCH_ADDED)
+        assert patch.patch == BLOB_PATCH_ADDED
 
     def test_patch_create_from_blob_buffer_delete(self):
         old_blob = self.repo[BLOB_OLD_SHA]
@@ -140,21 +142,15 @@ class PatchTest(utils.RepoTestCase):
             new_as_path=BLOB_NEW_PATH,
         )
 
-        self.assertEqual(patch.patch, BLOB_PATCH_DELETED)
+        assert patch.patch == BLOB_PATCH_DELETED
 
     def test_patch_create_from_bad_old_type_arg(self):
-        with self.assertRaises(TypeError):
-            pygit2.Patch.create_from(
-                self.repo,
-                BLOB_NEW_CONTENT,
-            )
+        with pytest.raises(TypeError):
+            pygit2.Patch.create_from(self.repo, BLOB_NEW_CONTENT)
 
     def test_patch_create_from_bad_new_type_arg(self):
-        with self.assertRaises(TypeError):
-            pygit2.Patch.create_from(
-                None,
-                self.repo,
-            )
+        with pytest.raises(TypeError):
+            pygit2.Patch.create_from(None, self.repo)
 
     def test_context_lines(self):
         old_blob = self.repo[BLOB_OLD_SHA]
@@ -171,7 +167,7 @@ class PatchTest(utils.RepoTestCase):
             len([line for line in patch.patch.splitlines() if line.startswith(" ")])
         )
 
-        self.assertNotEqual(context_count, 0)
+        assert context_count != 0
 
     def test_no_context_lines(self):
         old_blob = self.repo[BLOB_OLD_SHA]
@@ -189,7 +185,7 @@ class PatchTest(utils.RepoTestCase):
             len([line for line in patch.patch.splitlines() if line.startswith(" ")])
         )
 
-        self.assertEqual(context_count, 0)
+        assert context_count == 0
 
 
     def test_patch_create_blob_blobs(self):
@@ -203,7 +199,7 @@ class PatchTest(utils.RepoTestCase):
             new_as_path=BLOB_NEW_PATH,
         )
 
-        self.assertEqual(patch.patch, BLOB_PATCH)
+        assert patch.patch == BLOB_PATCH
 
     def test_patch_create_blob_buffer(self):
         blob = self.repo[self.repo.create_blob(BLOB_OLD_CONTENT)]
@@ -214,7 +210,7 @@ class PatchTest(utils.RepoTestCase):
             new_as_path=BLOB_NEW_PATH,
         )
 
-        self.assertEqual(patch.patch, BLOB_PATCH)
+        assert patch.patch == BLOB_PATCH
 
     def test_patch_create_blob_delete(self):
         blob = self.repo[self.repo.create_blob(BLOB_OLD_CONTENT)]
@@ -225,7 +221,7 @@ class PatchTest(utils.RepoTestCase):
             new_as_path=BLOB_NEW_PATH,
         )
 
-        self.assertEqual(patch.patch, BLOB_PATCH_DELETED)
+        assert patch.patch == BLOB_PATCH_DELETED
 
     def test_patch_create_blob_add(self):
         blob = self.repo[self.repo.create_blob(BLOB_NEW_CONTENT)]
@@ -236,7 +232,7 @@ class PatchTest(utils.RepoTestCase):
             new_as_path=BLOB_NEW_PATH,
         )
 
-        self.assertEqual(patch.patch, BLOB_PATCH_ADDED)
+        assert patch.patch == BLOB_PATCH_ADDED
 
     def test_patch_delete_blob(self):
         blob = self.repo[BLOB_OLD_SHA]
@@ -250,7 +246,7 @@ class PatchTest(utils.RepoTestCase):
         # Make sure that even after deleting the blob the patch still has the
         # necessary references to generate its patch
         del blob
-        self.assertEqual(patch.patch, BLOB_PATCH_DELETED)
+        assert patch.patch == BLOB_PATCH_DELETED
 
     def test_patch_multi_blob(self):
         blob = self.repo[BLOB_OLD_SHA]
@@ -267,7 +263,7 @@ class PatchTest(utils.RepoTestCase):
         )
         patch_text2 = patch.patch
 
-        self.assertEqual(patch_text, patch_text2)
-        self.assertEqual(patch_text, patch.patch)
-        self.assertEqual(patch_text2, patch2.patch)
-        self.assertEqual(patch.patch, patch2.patch)
+        assert patch_text == patch_text2
+        assert patch_text == patch.patch
+        assert patch_text2 == patch2.patch
+        assert patch.patch == patch2.patch
