@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 #
-# Copyright 2010-2017 The pygit2 contributors
+# Copyright 2010-2019 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -27,9 +27,11 @@
 
 from __future__ import absolute_import
 from __future__ import unicode_literals
-import unittest
+
 import time
 
+import pytest
+
 from pygit2 import Signature
 from .utils import NoRepoTestCase
 
@@ -40,43 +42,33 @@ class SignatureTest(NoRepoTestCase):
         signature = Signature(
             'Foo Ibáñez', 'foo@example.com', 1322174594, 60)
         encoding = signature._encoding
-        self.assertEqual(encoding, 'utf-8')
-        self.assertEqual(signature.name, signature.raw_name.decode(encoding))
-        self.assertEqual(signature.name.encode(encoding), signature.raw_name)
-        self.assertEqual(signature.email,
-                         signature.raw_email.decode(encoding))
-        self.assertEqual(signature.email.encode(encoding),
-                         signature.raw_email)
+        assert encoding == 'utf-8'
+        assert signature.name == signature.raw_name.decode(encoding)
+        assert signature.name.encode(encoding) == signature.raw_name
+        assert signature.email == signature.raw_email.decode(encoding)
+        assert signature.email.encode(encoding) == signature.raw_email
 
     def test_ascii(self):
-        self.assertRaises(UnicodeEncodeError,
-            Signature, 'Foo Ibáñez', 'foo@example.com', encoding='ascii')
+        with pytest.raises(UnicodeEncodeError):
+            Signature('Foo Ibáñez', 'foo@example.com', encoding='ascii')
 
     def test_latin1(self):
         encoding = 'iso-8859-1'
         signature = Signature(
             'Foo Ibáñez', 'foo@example.com', encoding=encoding)
-        self.assertEqual(encoding, signature._encoding)
-        self.assertEqual(signature.name, signature.raw_name.decode(encoding))
-        self.assertEqual(signature.name.encode(encoding), signature.raw_name)
-        self.assertEqual(signature.email,
-                         signature.raw_email.decode(encoding))
-        self.assertEqual(signature.email.encode(encoding),
-                         signature.raw_email)
+        assert encoding == signature._encoding
+        assert signature.name == signature.raw_name.decode(encoding)
+        assert signature.name.encode(encoding) == signature.raw_name
+        assert signature.email == signature.raw_email.decode(encoding)
+        assert signature.email.encode(encoding) == signature.raw_email
 
     def test_now(self):
         encoding = 'utf-8'
         signature = Signature(
             'Foo Ibáñez', 'foo@example.com', encoding=encoding)
-        self.assertEqual(encoding, signature._encoding)
-        self.assertEqual(signature.name, signature.raw_name.decode(encoding))
-        self.assertEqual(signature.name.encode(encoding), signature.raw_name)
-        self.assertEqual(signature.email,
-                         signature.raw_email.decode(encoding))
-        self.assertEqual(signature.email.encode(encoding),
-                         signature.raw_email)
-        self.assertTrue(abs(signature.time - time.time()) < 5)
-
-
-if __name__ == '__main__':
-    unittest.main()
+        assert encoding == signature._encoding
+        assert signature.name == signature.raw_name.decode(encoding)
+        assert signature.name.encode(encoding) == signature.raw_name
+        assert signature.email == signature.raw_email.decode(encoding)
+        assert signature.email.encode(encoding) == signature.raw_email
+        assert abs(signature.time - time.time()) < 5
