@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2010-2017 The pygit2 contributors
+# Copyright 2010-2019 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -29,7 +29,6 @@
 
 from __future__ import absolute_import
 from __future__ import unicode_literals
-import unittest
 
 from . import utils
 
@@ -48,8 +47,8 @@ class TreeBuilderTest(utils.BareRepoTestCase):
         bld = self.repo.TreeBuilder(TREE_SHA)
         result = bld.write()
 
-        self.assertEqual(len(bld), len(tree))
-        self.assertEqual(tree.id, result)
+        assert len(bld) == len(tree)
+        assert tree.id == result
 
 
     def test_noop_treebuilder_from_tree(self):
@@ -57,8 +56,8 @@ class TreeBuilderTest(utils.BareRepoTestCase):
         bld = self.repo.TreeBuilder(tree)
         result = bld.write()
 
-        self.assertEqual(len(bld), len(tree))
-        self.assertEqual(tree.id, result)
+        assert len(bld) == len(tree)
+        assert tree.id == result
 
 
     def test_rebuild_treebuilder(self):
@@ -66,14 +65,10 @@ class TreeBuilderTest(utils.BareRepoTestCase):
         bld = self.repo.TreeBuilder()
         for entry in tree:
             name = entry.name
-            self.assertTrue(bld.get(name) is None)
+            assert bld.get(name) is None
             bld.insert(name, entry.hex, entry.filemode)
-            self.assertEqual(bld.get(name).id, entry.id)
+            assert bld.get(name).id == entry.id
         result = bld.write()
 
-        self.assertEqual(len(bld), len(tree))
-        self.assertEqual(tree.id, result)
-
-
-if __name__ == '__main__':
-    unittest.main()
+        assert len(bld) == len(tree)
+        assert tree.id == result
